import type { UserPublic } from './user'

export type ChoreFrequency = 'one_time' | 'daily' | 'weekly' | 'monthly' | 'custom'
export type ChoreType = 'personal' | 'group'

export interface Chore {
  id: number
  group_id?: number | null
  name: string
  description?: string | null
  created_by_id: number
  frequency: ChoreFrequency
  custom_interval_days?: number | null
  next_due_date: string
  last_completed_at?: string
  created_at: string
  updated_at: string
  type: ChoreType
  creator?: {
    id: number
    name: string
    email: string
  }
  assignments?: ChoreAssignment[]
  is_completed: boolean
  completed_at: string | null
}

export interface ChoreCreate extends Omit<Chore, 'id'> { }

export interface ChoreUpdate extends Partial<ChoreCreate> { }

// Chore Assignment Types
export interface ChoreAssignment {
  id: number
  chore_id: number
  assigned_to_id: number
  assigned_by_id: number
  due_date: string
  is_complete: boolean
  completed_at: string | null
  created_at: string
  updated_at: string
  chore?: Chore
  assigned_user?: UserPublic
}

export interface ChoreAssignmentCreate {
  chore_id: number
  assigned_to_id: number
  due_date: string
}

export interface ChoreAssignmentUpdate {
  due_date?: string
  is_complete?: boolean
}
